@@ -10,7 +10,8 @@
 ##' @usage
 ##'cluscata(Data, nblo, NameBlocks=NULL, NameVar=NULL, Noise_cluster=FALSE,
 ##'         Itermax=30, Graph_dend=TRUE, Graph_bar=TRUE, printlevel=FALSE,
-##'         gpmax=min(6, nblo-2), Testonlyoneclust=TRUE, alpha=0.05, nperm=50, Warnings=FALSE)
+##'         gpmax=min(6, nblo-2), Testonlyoneclust=FALSE, alpha=0.05,
+##'         nperm=50, Warnings=FALSE)
 ##'
 ##' @param Data data frame or matrix where the blocks of binary variables are merged horizontally. If you have a different format, see \code{\link{change_cata_format}}
 ##'
@@ -32,7 +33,7 @@
 ##'
 ##' @param gpmax logical. What is maximum number of clusters to consider? Default: min(6, nblo-2)
 ##'
-##' @param Testonlyoneclust logical. Test if there is more than one cluster? Default: TRUE
+##' @param Testonlyoneclust logical. Test if there is more than one cluster? Default: FALSE
 ##'
 ##' @param alpha numerical between 0 and 1. What is the threshold to test if there is more than one cluster? Default: 0.05
 ##'
@@ -100,7 +101,7 @@
 
 cluscata=function(Data, nblo, NameBlocks=NULL, NameVar=NULL, Noise_cluster=FALSE, Itermax=30,
                   Graph_dend=TRUE, Graph_bar=TRUE, printlevel=FALSE,gpmax=min(6, nblo-2),
-                  Testonlyoneclust=TRUE, alpha=0.05, nperm=50, Warnings=FALSE){
+                  Testonlyoneclust=FALSE, alpha=0.05, nperm=50, Warnings=FALSE){
 
   #initialisation
   n=nrow(Data)
