@@ -10,7 +10,7 @@
 ##' @usage
 ##'  clustatis(Data,Blocks,NameBlocks=NULL,Noise_cluster=FALSE,scale=FALSE,
 ##'   Itermax=30, Graph_dend=TRUE, Graph_bar=TRUE,
-##'   printlevel=FALSE, gpmax=min(6, length(Blocks)-2), Testonlyoneclust=TRUE,
+##'   printlevel=FALSE, gpmax=min(6, length(Blocks)-2), Testonlyoneclust=FALSE,
 ##'   alpha=0.05, nperm=50)
 ##'
 ##'
@@ -34,7 +34,7 @@
 ##'
 ##' @param gpmax logical. What is maximum number of clusters to consider? Default: min(6, length(Blocks)-2)
 ##'
-##' @param Testonlyoneclust logical. Test if there is more than one cluster? Default: TRUE
+##' @param Testonlyoneclust logical. Test if there is more than one cluster? Default: FALSE
 ##'
 ##' @param alpha numerical between 0 and 1. What is the threshold to test if there is more than one cluster? Default: 0.05
 ##'
@@ -105,7 +105,7 @@
 
 clustatis=function(Data,Blocks,NameBlocks=NULL,Noise_cluster=FALSE, scale=FALSE,
                    Itermax=30, Graph_dend=TRUE, Graph_bar=TRUE,
-                   printlevel=FALSE, gpmax=min(6, length(Blocks)-2), Testonlyoneclust=TRUE,
+                   printlevel=FALSE, gpmax=min(6, length(Blocks)-2), Testonlyoneclust=FALSE,
                    alpha=0.05, nperm=50){
 
 
