@@ -10,7 +10,7 @@
 ##' @usage
 ##'clustatis_FreeSort(Data, NameSub=NULL, Noise_cluster=FALSE,Itermax=30,
 ##'                            Graph_dend=TRUE, Graph_bar=TRUE, printlevel=FALSE,
-##'                            gpmax=min(6, ncol(Data)-1), Testonlyoneclust=TRUE,
+##'                            gpmax=min(6, ncol(Data)-1), Testonlyoneclust=FALSE,
 ##'                            alpha=0.05, nperm=50)
 ##'
 ##'
@@ -30,7 +30,7 @@
 ##'
 ##' @param gpmax logical. What is maximum number of clusters to consider? Default: min(6, ncol(Data)-1)
 ##'
-##' @param Testonlyoneclust logical. Test if there is more than one cluster? Default: TRUE
+##' @param Testonlyoneclust logical. Test if there is more than one cluster? Default: FALSE
 ##'
 ##' @param alpha numerical between 0 and 1. What is the threshold to test if there is more than one cluster? Default: 0.05
 ##'
@@ -93,7 +93,7 @@
 
 clustatis_FreeSort=function(Data,NameSub=NULL, Noise_cluster=FALSE,Itermax=30,
                         Graph_dend=TRUE, Graph_bar=TRUE, printlevel=FALSE,
-                        gpmax=min(6, ncol(Data)-1), Testonlyoneclust=TRUE,
+                        gpmax=min(6, ncol(Data)-1), Testonlyoneclust=FALSE,
                         alpha=0.05, nperm=50)
 {
 
